from setuptools import setup

setup(name='distributions_pranav',
      version='0.1',
      description='Gaussian distributions',
      packages=['distributions_pranav'],
      author_email='nspranav1180@gmail.com',
      zip_safe=False)
